.. Open Knowledge Foundation RDF documentation master file, created by
   sphinx-quickstart on Wed May 19 12:50:05 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ORDF Documentation
==================

`ORDF`_ is the `Open Knowledge Foundation`_'s library of support
infrastructure for RDF_. It is available from

    * PyPi: http://pypi.python.org/pypi/ordf/
    * Mercurial: http://ordf.org/src/

It is based on RDFLib_ and contains an object-description mapper, support 
for multiple back-end indices, message passing, revision history and
provenance, a namespace library and  a variety of helper functions and
modules to ease integration with the Pylons_ framework.

Contents:

.. toctree::
   :maxdepth: 2

   design_considerations
   notation3
   graphs
   distribution
   administration
   cmdline
   api_docs


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _ORDF: http://ordf.org/
.. _Open Knowledge Foundation: http://okfn.org/
.. _mercurial repository: http://ordf.org/src/
.. _RDF: http://en.wikipedia.org/wiki/Resource_Description_Framework
.. _RDFLib: http://www.rdflib.net/
.. _Pylons: http://pylonshq.com/
